@@ -32,11 +32,12 @@ use std::str::FromStr;
 use crate::Collection;
 
 impl<T: DeserializeOwned + Unpin + Send + Sync> Collection<T> {
-    pub async fn get_one(&self, id: &str) -> Result<Option<T>> {
+    pub async fn get_one(&self, id: &str) -> Result<T> {
         let item = self
             .collection
             .find_one(Some(doc! { "_id": ObjectId::from_str(id).unwrap() }), None)
-            .await?;
+            .await?
+            .unwrap();
         Ok(item)
     }
 }
